@@ -20,5 +20,18 @@ class DMSAPIYAMLExporter(DMSAPIExporter, DMSFileExporter[RequestSchema]):
         if file_path.suffix.lower() not in {".yaml", ".yml"}:
             raise ValueError("The file path must have a .yaml or .yml extension.")
 
-        api_format = data_model.model_dump(mode="json")
+        api_format = data_model.model_dump(mode="json", by_alias=True)
         file_path.write_text(yaml.safe_dump(api_format, sort_keys=False), encoding=self.ENCODING, newline=self.NEW_LINE)
+
+
+class DMSAPIJSONExporter(DMSAPIExporter, DMSFileExporter[RequestSchema]):
+    def export_to_file(self, data_model: RequestSchema, file_path: Path) -> None:
+        """Export the data model to a JSON file in API format."""
+        if file_path.suffix.lower() != ".json":
+            raise ValueError("The file path must have a .json extension.")
+
+        file_path.write_text(
+            data_model.model_dump_json(by_alias=True),
+            encoding=self.ENCODING,
+            newline=self.NEW_LINE,
+        )
