@@ -3,6 +3,7 @@ from collections import defaultdict
 from dataclasses import dataclass, field
 from typing import Any, Literal
 
+from cognite.neat._data_model._constants import DEFAULT_MAX_LIST_SIZE, DEFAULT_MAX_LIST_SIZE_DIRECT_RELATIONS
 from cognite.neat._data_model.importers._table_importer.data_classes import (
     DMSContainer,
     DMSEnum,
@@ -54,9 +55,10 @@ class ContainerProperties:
 
 
 class DMSTableWriter:
-    def __init__(self, default_space: str, default_version: str) -> None:
+    def __init__(self, default_space: str, default_version: str, skip_properties_in_other_spaces: bool) -> None:
         self.default_space = default_space
         self.default_version = default_version
+        self.skip_properties_in_other_spaces = skip_properties_in_other_spaces
 
     ## Main Entry Point ###
     def write_tables(self, schema: RequestSchema) -> TableDMS:
@@ -176,7 +178,12 @@ class DMSTableWriter:
     @staticmethod
     def _write_container_property_max_count(dtype: DataType) -> int | None:
         if isinstance(dtype, ListablePropertyTypeDefinition) and dtype.list:
-            return dtype.max_list_size
+            if dtype.max_list_size is not None:
+                return dtype.max_list_size
+            elif isinstance(dtype, DirectNodeRelation):
+                return DEFAULT_MAX_LIST_SIZE_DIRECT_RELATIONS
+            else:
+                return DEFAULT_MAX_LIST_SIZE
         return 1
 
     @staticmethod
@@ -279,6 +286,8 @@ class DMSTableWriter:
         for view in views:
             if not view.properties:
                 continue
+            if self.skip_properties_in_other_spaces and view.space != self.default_space:
+                continue
             for prop_id, prop in view.properties.items():
                 output.properties.append(self._write_view_property(view, prop_id, prop, container))
                 if isinstance(prop, EdgeProperty):
